@@ -1,6 +1,6 @@
 use discord_md::ast::MarkdownDocument;
 use discord_md::builder::*;
-use discord_md::generate::MarkdownToString;
+use discord_md::generate::{ToMarkdownString, ToMarkdownStringOption};
 use discord_md::parse;
 
 #[test]
@@ -20,5 +20,8 @@ fn test_generate_then_parse() {
         multi_line_code("\nsome\ncode", None),
     ]);
 
-    assert_eq!(parse(&ast.to_markdown_string()), ast);
+    assert_eq!(
+        parse(&ast.to_markdown_string(&ToMarkdownStringOption::new())),
+        ast
+    );
 }
